@@ -12,7 +12,7 @@
 	Copyright (C) 2004
 	Martin Michlmayr <tbm@cyrius.com>
 
-	Copyright (C) 2004-2007,2009,2010,2013,2014,2016 
+	Copyright (C) 2004-2007,2009,2010,2013,2014,2016-2018
 	Helge Kreutzmann <debian@helgefjell.de>
 
 
@@ -25,30 +25,7 @@
 	1.0.4	AIB	20010909	Added getphysicalmemory() call
 	1.0.5   OPAL    20030417        Added Athlon XP and MP.
 	1.0.6   KRE     20040711        Added Opteron
-	1.0.7   KRE     20040726        Added Pentium M
-	1.0.8   KRE     20040809        Add further machines (Athlons, Xeons,
-					Pentium 4s, Celerons), fix detection of
-					Pentium MMX
-	1.0.9   KRE     20050215        Added several amd64 machines
-	1.0.10  KRE     20051106        Added another Pentium4 machine
-	1.0.11  KRE     20051113        Added another Celeron machine
-	1.0.12  KRE     20051120        Include <string.h>
-	1.0.13  KRE     20060212        Add an AMP sempron cpu
-	1.0.14  KRE     20060423        Add another AMD Sempron
-	1.0.15  KRE     20060724        One more am64 and one pentium M added
-	1.0.16  KRE     20070716        Added a Geode CPU
-	1.0.17  KRE     20070810        Added another Xeon
-	1.0.18  KRE     20080203        Added Core 2 and one more Pentium 4
-	1.0.19  KRE     20090318        Added Core Solo
-	1.0.20  KRE     20090524        Add another Xeon
-	1.0.21  KRE     20090605        Add another Core Duo
-	1.0.22  KRE     20100228        Add another Core Duo
-	1.0.23  KRE     20110725        Add a Phenom
-	1.0.24  KRE     20111104        Add another Xeon
-	1.0.25  KRE     20130527        Add an Athlon X2
-	1.0.26  KRE     20131114        Add another Xeon
-	1.0.27  KRE     20131114        Add another AMD
-	1.0.28  KRE     20160918        Determine fastest CPU
+	see git history for later changes
 
         This is the x86 port of linuxinfo
 */
@@ -89,13 +66,14 @@ static char *models[] =
         "AMD Athlon\\(tm\\) XP [0-9]{4}+", "Athlon XP",
         "AMD Athlon\\(TM\\) MP", "Athlon MP",
 	"AMD Opteron\\(tm\\) Processor [0-9]{3}","Opteron",
+	"AMD Opteron\\(tm\\) X3421 APU", "Opteron APU",
 	"AMD Opteron 23xx \\(Gen 3 Class Opteron\\)", "Opteron Gen 3",
 	"AMD Sempron\\(tm\\)   [0-9]{4}+", "Sempron",
 	"AMD Athlon\\(tm\\) 64 Processor [0-9]{4}+", "x86_64",
 	"AMD Athlon\\(tm\\) 64 X2 Dual Core Processor [0-9]{4}+", "x86_64",
-	"AMD Athlon\\(tm\\) II X4 [0-9]{3} Processor", "Athlon(tm) II",
+	"AMD Athlon\\(tm\\) II X4 [0-9]{3} Processor", "Athlon II",
+	"AMD Phenom\\(tm\\) II X4 965 Processor", "Phenom II",
 	"AMD Phenom\\(tm\\) II X6 1055T Processor", "Phenom II",
-	"Intel\\(R\\) Xeon\\(TM\\) CPU [0-9]\\.[0-9]{2}GHz", "Xeon",
 	"AMD A6-6310 APU with AMD Radeon R4 Graphics", "A6-6310 with Radeon R4",
 	"AMD FX\\(tm\\)-4300 Quad-Core Processor", "x86_64 FX",
         "Am5x86", "5x86",
@@ -118,9 +96,12 @@ static char *models[] =
 	"Intel\\(R\\) Pentium\\(R\\) 4 CPU [0-9]\\.[0-9]{2}GHz", "Pentium 4",
 	"Intel\\(R\\) Pentium\\(R\\) M processor", "Pentium M",
 	"Intel\\(R\\) Pentium\\(R\\) M processor [0-9]{4}MHz", "Pentium M",
+	"Intel\\(R\\) Pentium\\(R\\) 4 Mobile CPU [0-9]\\.[0-9]{2}GHz","Pentium 4 Mobile",
 	"Intel\\(R\\) XEON\\(TM\\) CPU [0-9]\\.[0-9]{2}GHz", "Xeon",
+	"Intel\\(R\\) Xeon\\(TM\\) CPU [0-9]\\.[0-9]{2}GHz", "Xeon",
 	"Intel\\(R\\) Xeon\\(R\\) CPU           E5345  @ [0-9]\\.[0-9]{2}GHz","Xeon",
 	"Intel\\(R\\) Xeon\\(R\\) CPU           L5420  @ [0-9]\\.[0-9]{2}GHz","Xeon",
+	"Intel\\(R\\) Xeon\\(R\\) CPU E5-2650 v3 @ [0-9]\\.[0-9]{2}GHz", "Xeon",
         "Celeron \\(Coppermine\\)", "Celeron (Coppermine)",
         "Celeron \\(Mendocino\\)", "Celeron (Mendocino)",
         "Celeron \\(Covington\\)", "Celeron (Covington)",
@@ -129,20 +110,18 @@ static char *models[] =
 	"Mobile Intel\\(R\\) Celeron\\(TM\\) CPU          [0-9]{3}MHz", "Mobile Celeron",
 	"Mobile Intel\\(R\\) Pentium\\(R\\) 4     CPU [0-9]\\.[0-9]{2}GHz", "Mobile Pentium 4",
 	"Intel\\(R\\) Core\\(TM\\) Solo CPU     U1400  @ [0-9]\\.[0-9]{2}GHz", "Core Solo",
-	"Intel\\(R\\) Core\\(TM\\) i7-4600M CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
 	"Intel\\(R\\) Core\\(TM\\)2 CPU          6600  @ [0-9]\\.[0-9]{2}GHz", "Core 2",
-	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E6750  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
+	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E[0-9]{3}0  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
 	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     P8600  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
-	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E7400  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
-	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E8400  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
 	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q6600  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Quad",
 	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q9550  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Quad",
-	"Intel\\(R\\) Core\\(TM\\) i5-4210U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
-	"Intel\\(R\\) Core\\(TM\\) i5-6200U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
 	"Intel\\(R\\) Core\\(TM\\) i5-6600 CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
+	"Intel\\(R\\) Core\\(TM\\) i5-[0-9]{3}0U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
 	"Intel\\(R\\) Core\\(TM\\) i7-6600U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
+	"Intel\\(R\\) Core\\(TM\\) i7-6700T CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
+	"Intel\\(R\\) Core\\(TM\\) i7-4600M CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
 	"Genuine Intel\\(R\\) CPU            2140  @ [0-9]\\.[0-9]{2}GHz", "Pentium 4",
-	"Intel\\(R\\) Atom\\(TM\\) CPU N450   @ [0-9]\\.[0-9]{2}GHz", "Atom",
+	"Intel\\(R\\) Atom\\(TM\\) CPU N[0-9]{2}0   @ [0-9]\\.[0-9]{2}GHz", "Atom",
 #else
 	"K6 (166 - 266)", "K6",
         "AMD-K6tm w/ mul", "K6 (MMX)",
@@ -162,6 +141,7 @@ static char *models[] =
 	"AMD Opteron(tm) Processor 244", "Opteron",
 	"AMD Opteron(tm) Processor 246", "Opteron",
 	"AMD Opteron(tm) Processor 248", "Opteron",
+	"AMD Opteron(tm) X3421 APU", "Opteron APU",
 	"AMD Opteron 23xx (Gen 3 Class Opteron)", "Opteron Gen 3",
 	"AMD Sempron(tm)   2300+", "Sempron",
 	"AMD Sempron(tm)   2600+", "Sempron",
@@ -172,7 +152,8 @@ static char *models[] =
 	"AMD Athlon(tm) 64 Processor 3500+", "x86_64",
 	"AMD Athlon(tm) 64 Processor 3700+", "x86_64",
 	"AMD Athlon(tm) 64 X2 Dual Core Processor 5400+", "x86_64",
-	"AMD Athlon(tm) II X4 620 Processor", "Athlon(tm) II",
+	"AMD Athlon(tm) II X4 620 Processor", "Athlon II",
+	"AMD Phenom(tm) II X4 965 Processor", "Phenom II",
 	"AMD Phenom(tm) II X6 1055T Processor", "Phenom II",
 	"AMD A6-6310 APU with AMD Radeon R4 Graphics", "A6-6310 with Radeon R4",
 	"AMD FX(tm)-4300 Quad-Core Processor", "x86_64 FX",
@@ -200,6 +181,7 @@ static char *models[] =
 	"Intel(R) Pentium(R) 4 CPU 3.20GHz", "Pentium 4",
 	"Intel(R) Pentium(R) M processor", "Pentium M",
 	"Intel(R) Pentium(R) M processor 1600MHz", "Pentium M",
+	"Intel(R) Pentium(R) 4 Mobile CPU 1.80GHz","Pentium 4 Mobile",
 	"Intel(R) XEON(TM) CPU 2.20GHz", "Xeon",
 	"Intel(R) XEON(TM) CPU 2.40GHz", "Xeon",
 	"Intel(R) Xeon(TM) CPU 3.00GHz", "Xeon",
@@ -208,6 +190,7 @@ static char *models[] =
 	"Intel(R) Xeon(TM) CPU 3.60GHz", "Xeon",
 	"Intel(R) Xeon(R) CPU           E5345  @ 2.33GHz","Xeon",
 	"Intel(R) Xeon(R) CPU           L5420  @ 2.50GHz","Xeon",
+	"Intel(R) Xeon(R) CPU E5-2650 v3 @ 2.30GHz", "Xeon",
         "Celeron (Coppermine)", "Celeron (Coppermine)",
         "Celeron (Mendocino)", "Celeron (Mendocino)",
         "Celeron (Covington)", "Celeron (Covington)",
@@ -218,20 +201,24 @@ static char *models[] =
 	"Mobile Intel(R) Celeron(TM) CPU          733MHz", "Mobile Celeron",
 	"Mobile Intel(R) Pentium(R) 4     CPU 3.06GHz", "Mobile Pentium 4",
 	"Intel(R) Core(TM) Solo CPU     U1400  @ 1.20GHz", "Core Solo",
-	"Intel(R) Core(TM) i7-4600M CPU @ 2.90GHz", "Core i7",
 	"Intel(R) Core(TM)2 CPU          6600  @ 2.40GHz", "Core 2",
 	"Intel(R) Core(TM)2 Duo CPU     E6750  @ 2.66GHz", "Core 2 Duo",
-	"Intel(R) Core(TM)2 Duo CPU     P8600  @ 2.40GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Duo CPU     E7400  @ 2.80GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Duo CPU     E8400  @ 3.00GHz", "Core 2 Duo",
+	"Intel(R) Core(TM)2 Duo CPU     P8600  @ 2.40GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Quad CPU    Q6600  @ 2.40GHz", "Core 2 Quad",
 	"Intel(R) Core(TM)2 Quad CPU    Q9550  @ 2.83GHz", "Core 2 Quad",
 	"Intel(R) Core(TM) i5-4210U CPU @ 1.70GHz", "Core i5",
+	"Intel(R) Core(TM) i5-5300U CPU @ 2.30GHz", "Core i5",
 	"Intel(R) Core(TM) i5-6200U CPU @ 2.30GHz", "Core i5",
+	"Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz", "Core i5",
 	"Intel(R) Core(TM) i5-6600 CPU @ 3.30GHz", "Core i5",
+	"Intel(R) Core(TM) i7-4600M CPU @ 2.90GHz", "Core i7",
 	"Intel(R) Core(TM) i7-6600U CPU @ 2.60GHz", "Core i7",
+	"Intel(R) Core(TM) i7-6700T CPU @ 2.80GHz", "Core i7",
 	"Genuine Intel(R) CPU            2140  @ 1.60GHz", "Pentium 4",
 	"Intel(R) Atom(TM) CPU N450   @ 1.66GHz", "Atom",
+	"Intel(R) Atom(TM) CPU N270   @ 1.60GHz", "Atom",
 #endif
         NULL, NULL
 };
