@@ -6,7 +6,7 @@
 
         Alex Buell <alex.buell@munted.eu>
 
-	Copyright (C) 2005,2006
+	Copyright (C) 2005,2006,2014
 	Helge Kreutzmann <debian@helgefjell.de>
 
         Version Author  Date            Comments
@@ -16,7 +16,7 @@
 	1.0.2	AIB	20010129	Fixed bug and added Fujitsu
 	1.0.3	AIB	20010909	Complete rewrite
 	1.0.4   HKM     20060723        Added more machines and fixed a typo
-	1.0.5   HKM     20061017        Added the Niagra
+	see git history for later changes
 
         This is the Sparc32 port of linuxinfo
 */
